@@ -1,6 +1,6 @@
 import json
-import warnings
 import os
+
 import selenium_profiles
 
 
@@ -29,7 +29,7 @@ def read_json(filename: str = 'example.json', encoding: str = "utf-8",sel_root=T
         path = sel_profiles_path() + filename
     else:
         path = filename
-    with open(sel_profiles_path() + filename, 'r', encoding=encoding) as f:
+    with open(path, 'r', encoding=encoding) as f:
         return json.load(f)
 
 
@@ -40,3 +40,12 @@ def write_json(obj: dict or list, filename: str = "out.json", encoding: str = "u
         path = filename
     with open(path, "w", encoding=encoding) as outfile:
         outfile.write(json.dumps(obj))
+
+def check_cmd(value, values):
+    if value not in values:
+        raise ValueError("got " + str(value) + " , but expected " + str(values))
+
+def valid_key(got:list or set, valid:list, obj_name:str):
+    for key in got:
+        if key not in valid:
+            raise ValueError(f"'{key}' isn't a valid key for {obj_name}")
